@@ -13,7 +13,7 @@ class AIconLabel : public ALabel {
              const std::string &format, uint16_t interval = 0, bool ellipsize = false,
              bool enable_click = false, bool enable_scroll = false);
   virtual ~AIconLabel() = default;
-  virtual auto update() -> void;
+  auto update() -> void override;
 
  protected:
   Gtk::Image image_;
