@@ -12,6 +12,7 @@
 #include <vector>
 
 #include "AModule.hpp"
+#include "group.hpp"
 #include "xdg-output-unstable-v1-client-protocol.h"
 
 namespace waybar {
@@ -91,6 +92,9 @@ class Bar {
   bool vertical = false;
   Gtk::Window window;
 
+  int x_global;
+  int y_global;
+
 #ifdef HAVE_SWAY
   std::string bar_id;
 #endif
@@ -98,15 +102,20 @@ class Bar {
  private:
   void onMap(GdkEventAny *);
   auto setupWidgets() -> void;
-  void getModules(const Factory &, const std::string &, Gtk::Box *);
+  void getModules(const Factory &, const std::string &, waybar::Group *);
   void setupAltFormatKeyForModule(const std::string &module_name);
   void setupAltFormatKeyForModuleList(const char *module_list_name);
   void setMode(const bar_mode &);
+  void onConfigure(GdkEventConfigure *ev);
+  void configureGlobalOffset(int width, int height);
+  void onOutputGeometryChanged();
 
   /* Copy initial set of modes to allow customization */
   bar_mode_map configured_modes = PRESET_MODES;
   std::string last_mode_{MODE_DEFAULT};
 
+  struct bar_margins margins_;
+
   std::unique_ptr<BarSurface> surface_impl_;
   Gtk::Box left_;
   Gtk::Box center_;
