@@ -1,5 +1,9 @@
+#pragma once
+
 #include <fmt/format.h>
 
+#include <string>
+
 #include "ALabel.hpp"
 #include "bar.hpp"
 #include "modules/hyprland/backend.hpp"
