@@ -1,5 +1,9 @@
+#pragma once
+
 #include <fmt/format.h>
 
+#include <string>
+
 #include "AAppIconLabel.hpp"
 #include "bar.hpp"
 #include "modules/hyprland/backend.hpp"
@@ -10,7 +14,7 @@ namespace waybar::modules::hyprland {
 class Window : public waybar::AAppIconLabel, public EventHandler {
  public:
   Window(const std::string&, const waybar::Bar&, const Json::Value&);
-  virtual ~Window();
+  ~Window() override;
 
   auto update() -> void override;
 
