@@ -481,6 +481,9 @@ waybar::Bar::Bar(struct waybar_output* w_output, const Json::Value& w_config)
     : output(w_output),
       config(w_config),
       window{Gtk::WindowType::WINDOW_TOPLEVEL},
+      x_global(0),
+      y_global(0),
+      margins_{.top = 0, .right = 0, .bottom = 0, .left = 0},
       left_(Gtk::ORIENTATION_HORIZONTAL, 0),
       center_(Gtk::ORIENTATION_HORIZONTAL, 0),
       right_(Gtk::ORIENTATION_HORIZONTAL, 0),
@@ -516,8 +519,6 @@ waybar::Bar::Bar(struct waybar_output* w_output, const Json::Value& w_config)
   uint32_t height = config["height"].isUInt() ? config["height"].asUInt() : 0;
   uint32_t width = config["width"].isUInt() ? config["width"].asUInt() : 0;
 
-  struct bar_margins margins_;
-
   if (config["margin-top"].isInt() || config["margin-right"].isInt() ||
       config["margin-bottom"].isInt() || config["margin-left"].isInt()) {
     margins_ = {
@@ -563,6 +564,10 @@ waybar::Bar::Bar(struct waybar_output* w_output, const Json::Value& w_config)
     margins_ = {.top = gaps, .right = gaps, .bottom = gaps, .left = gaps};
   }
 
+  window.signal_configure_event().connect_notify(sigc::mem_fun(*this, &Bar::onConfigure));
+  output->monitor->property_geometry().signal_changed().connect(
+      sigc::mem_fun(*this, &Bar::onOutputGeometryChanged));
+
 #ifdef HAVE_GTK_LAYER_SHELL
   bool use_gls = config["gtk-layer-shell"].isBool() ? config["gtk-layer-shell"].asBool() : true;
   if (use_gls) {
@@ -674,6 +679,7 @@ void waybar::Bar::onMap(GdkEventAny*) {
    */
   auto gdk_window = window.get_window()->gobj();
   surface = gdk_wayland_window_get_wl_surface(gdk_window);
+  configureGlobalOffset(gdk_window_get_width(gdk_window), gdk_window_get_height(gdk_window));
 }
 
 void waybar::Bar::setVisible(bool value) {
@@ -734,7 +740,7 @@ void waybar::Bar::handleSignal(int signal) {
 }
 
 void waybar::Bar::getModules(const Factory& factory, const std::string& pos,
-                             Gtk::Box* group = nullptr) {
+                             waybar::Group* group = nullptr) {
   auto module_list = group ? config[pos]["modules"] : config[pos];
   if (module_list.isArray()) {
     for (const auto& name : module_list) {
@@ -747,10 +753,11 @@ void waybar::Bar::getModules(const Factory& factory, const std::string& pos,
           auto id_name = ref.substr(6, hash_pos - 6);
           auto class_name = hash_pos != std::string::npos ? ref.substr(hash_pos + 1) : "";
 
-          auto parent = group ? group : &this->box_;
-          auto vertical = parent->get_orientation() == Gtk::ORIENTATION_VERTICAL;
+          auto vertical = (group ? group->getBox().get_orientation() : box_.get_orientation()) ==
+                          Gtk::ORIENTATION_VERTICAL;
+
           auto group_module = new waybar::Group(id_name, class_name, config[ref], vertical);
-          getModules(factory, ref, &group_module->box);
+          getModules(factory, ref, group_module);
           module = group_module;
         } else {
           module = factory.makeModule(ref);
@@ -759,7 +766,7 @@ void waybar::Bar::getModules(const Factory& factory, const std::string& pos,
         std::shared_ptr<AModule> module_sp(module);
         modules_all_.emplace_back(module_sp);
         if (group) {
-          group->pack_start(*module, false, false);
+          group->addWidget(*module);
         } else {
           if (pos == "modules-left") {
             modules_left_.emplace_back(module_sp);
@@ -815,3 +822,47 @@ auto waybar::Bar::setupWidgets() -> void {
     right_.pack_end(*module, false, false);
   }
 }
+
+void waybar::Bar::onConfigure(GdkEventConfigure* ev) {
+  configureGlobalOffset(ev->width, ev->height);
+}
+
+void waybar::Bar::configureGlobalOffset(int width, int height) {
+  auto monitor_geometry = *output->monitor->property_geometry().get_value().gobj();
+  auto position = config["position"].asString();
+  int x;
+  int y;
+  if (position == "bottom") {
+    if (width + margins_.left + margins_.right >= monitor_geometry.width)
+      x = margins_.left;
+    else
+      x = (monitor_geometry.width - width) / 2;
+    y = monitor_geometry.height - height - margins_.bottom;
+  } else if (position == "left") {
+    x = margins_.left;
+    if (height + margins_.top + margins_.bottom >= monitor_geometry.height)
+      y = margins_.top;
+    else
+      y = (monitor_geometry.height - height) / 2;
+  } else if (position == "right") {
+    x = monitor_geometry.width - width - margins_.right;
+    if (height + margins_.top + margins_.bottom >= monitor_geometry.height)
+      y = margins_.top;
+    else
+      y = (monitor_geometry.height - height) / 2;
+  } else {
+    // position is top
+    if (width + margins_.left + margins_.right >= monitor_geometry.width)
+      x = margins_.left;
+    else
+      x = (monitor_geometry.width - width) / 2;
+    y = margins_.top;
+  }
+
+  x_global = x + monitor_geometry.x;
+  y_global = y + monitor_geometry.y;
+}
+
+void waybar::Bar::onOutputGeometryChanged() {
+  configureGlobalOffset(window.get_width(), window.get_height());
+}
