@@ -1,5 +1,13 @@
 #include "factory.hpp"
 
+#ifdef HAVE_LIBPULSE
+#include "modules/pulseaudio_slider.hpp"
+#endif
+
+#ifdef HAVE_LIBUDEV
+#include "modules/backlight_slider.hpp"
+#endif
+
 waybar::Factory::Factory(const Bar& bar, const Json::Value& config) : bar_(bar), config_(config) {}
 
 waybar::AModule* waybar::Factory::makeModule(const std::string& name) const {
@@ -99,6 +107,17 @@ waybar::AModule* waybar::Factory::makeModule(const std::string& name) const {
     if (ref == "cpu") {
       return new waybar::modules::Cpu(id, config_[name]);
     }
+#if defined(HAVE_CPU_LINUX)
+    if (ref == "cpu_frequency") {
+      return new waybar::modules::CpuFrequency(id, config_[name]);
+    }
+#endif
+    if (ref == "cpu_usage") {
+      return new waybar::modules::CpuUsage(id, config_[name]);
+    }
+    if (ref == "load") {
+      return new waybar::modules::Load(id, config_[name]);
+    }
 #endif
     if (ref == "clock") {
       return new waybar::modules::Clock(id, config_[name]);
@@ -126,6 +145,9 @@ waybar::AModule* waybar::Factory::makeModule(const std::string& name) const {
     if (ref == "backlight") {
       return new waybar::modules::Backlight(id, config_[name]);
     }
+    if (ref == "backlight/slider") {
+      return new waybar::modules::BacklightSlider(id, config_[name]);
+    }
 #endif
 #ifdef HAVE_LIBEVDEV
     if (ref == "keyboard-state") {
@@ -136,6 +158,9 @@ waybar::AModule* waybar::Factory::makeModule(const std::string& name) const {
     if (ref == "pulseaudio") {
       return new waybar::modules::Pulseaudio(id, config_[name]);
     }
+    if (ref == "pulseaudio/slider") {
+      return new waybar::modules::PulseaudioSlider(id, config_[name]);
+    }
 #endif
 #ifdef HAVE_LIBMPDCLIENT
     if (ref == "mpd") {
