@@ -100,9 +100,11 @@ void waybar::modules::Battery::refreshBatteries() {
       }
       auto dir_name = node.path().filename();
       auto bat_defined = config_["bat"].isString();
+      bool bat_compatibility = config_["bat-compatibility"].asBool();
       if (((bat_defined && dir_name == config_["bat"].asString()) || !bat_defined) &&
           (fs::exists(node.path() / "capacity") || fs::exists(node.path() / "charge_now")) &&
-          fs::exists(node.path() / "uevent") && fs::exists(node.path() / "status") &&
+          fs::exists(node.path() / "uevent") &&
+          (fs::exists(node.path() / "status") || bat_compatibility) &&
           fs::exists(node.path() / "type")) {
         std::string type;
         std::ifstream(node.path() / "type") >> type;
@@ -252,7 +254,13 @@ const std::tuple<uint8_t, float, std::string, float> waybar::modules::Battery::g
     for (auto const& item : batteries_) {
       auto bat = item.first;
       std::string _status;
-      std::getline(std::ifstream(bat / "status"), _status);
+
+      /* Check for adapter status if battery is not available */
+      if (!std::ifstream(bat / "status")) {
+        std::getline(std::ifstream(adapter_ / "status"), _status);
+      } else {
+        std::getline(std::ifstream(bat / "status"), _status);
+      }
 
       // Some battery will report current and charge in μA/μAh.
       // Scale these by the voltage to get μW/μWh.
@@ -534,6 +542,13 @@ const std::tuple<uint8_t, float, std::string, float> waybar::modules::Battery::g
       }
     }
 
+    // Handle weighted-average
+    if ((config_["weighted-average"].isBool() ? config_["weighted-average"].asBool() : false) &&
+        total_energy_exists && total_energy_full_exists) {
+      if (total_energy_full > 0.0f)
+        calculated_capacity = ((float)total_energy * 100.0f / (float)total_energy_full);
+    }
+
     // Handle design-capacity
     if ((config_["design-capacity"].isBool() ? config_["design-capacity"].asBool() : false) &&
         total_energy_exists && total_energy_full_design_exists) {
