@@ -122,7 +122,9 @@ void waybar::modules::MPD::setLabel() {
   std::chrono::seconds elapsedTime, totalTime;
 
   std::string stateIcon = "";
-  if (stopped()) {
+  bool no_song = song_.get() == nullptr;
+  if (stopped() || no_song) {
+    if (no_song) spdlog::warn("Bug in mpd: no current song but state is not stopped.");
     format =
         config_["format-stopped"].isString() ? config_["format-stopped"].asString() : "stopped";
     label_.get_style_context()->add_class("stopped");
@@ -174,14 +176,14 @@ void waybar::modules::MPD::setLabel() {
 
   try {
     auto text = fmt::format(
-        format, fmt::arg("artist", artist.raw()), fmt::arg("albumArtist", album_artist.raw()),
-        fmt::arg("album", album.raw()), fmt::arg("title", title.raw()), fmt::arg("date", date),
-        fmt::arg("volume", volume), fmt::arg("elapsedTime", elapsedTime),
-        fmt::arg("totalTime", totalTime), fmt::arg("songPosition", song_pos),
-        fmt::arg("queueLength", queue_length), fmt::arg("stateIcon", stateIcon),
-        fmt::arg("consumeIcon", consumeIcon), fmt::arg("randomIcon", randomIcon),
-        fmt::arg("repeatIcon", repeatIcon), fmt::arg("singleIcon", singleIcon),
-        fmt::arg("filename", filename));
+        fmt::runtime(format), fmt::arg("artist", artist.raw()),
+        fmt::arg("albumArtist", album_artist.raw()), fmt::arg("album", album.raw()),
+        fmt::arg("title", title.raw()), fmt::arg("date", date), fmt::arg("volume", volume),
+        fmt::arg("elapsedTime", elapsedTime), fmt::arg("totalTime", totalTime),
+        fmt::arg("songPosition", song_pos), fmt::arg("queueLength", queue_length),
+        fmt::arg("stateIcon", stateIcon), fmt::arg("consumeIcon", consumeIcon),
+        fmt::arg("randomIcon", randomIcon), fmt::arg("repeatIcon", repeatIcon),
+        fmt::arg("singleIcon", singleIcon), fmt::arg("filename", filename));
     if (text.empty()) {
       label_.hide();
     } else {
@@ -198,7 +200,7 @@ void waybar::modules::MPD::setLabel() {
                                                           : "MPD (connected)";
     try {
       auto tooltip_text =
-          fmt::format(tooltip_format, fmt::arg("artist", artist.raw()),
+          fmt::format(fmt::runtime(tooltip_format), fmt::arg("artist", artist.raw()),
                       fmt::arg("albumArtist", album_artist.raw()), fmt::arg("album", album.raw()),
                       fmt::arg("title", title.raw()), fmt::arg("date", date),
                       fmt::arg("volume", volume), fmt::arg("elapsedTime", elapsedTime),
