@@ -209,8 +209,17 @@ WorkspaceGroup::WorkspaceGroup(const Bar &bar, Gtk::Box &box, const Json::Value
 }
 
 auto WorkspaceGroup::fill_persistent_workspaces() -> void {
-  if (config_["persistent_workspaces"].isObject() && !workspace_manager_.all_outputs()) {
-    const Json::Value &p_workspaces = config_["persistent_workspaces"];
+  if (config_["persistent_workspaces"].isObject()) {
+    spdlog::warn(
+        "persistent_workspaces is deprecated. Please change config to use persistent-workspaces.");
+  }
+
+  if ((config_["persistent-workspaces"].isObject() ||
+       config_["persistent_workspaces"].isObject()) &&
+      !workspace_manager_.all_outputs()) {
+    const Json::Value &p_workspaces = config_["persistent-workspaces"].isObject()
+                                          ? config_["persistent-workspaces"]
+                                          : config_["persistent_workspaces"];
     const std::vector<std::string> p_workspaces_names = p_workspaces.getMemberNames();
 
     for (const std::string &p_w_name : p_workspaces_names) {
