@@ -3,8 +3,13 @@
 #include <spdlog/sinks/stdout_sinks.h>
 #include <spdlog/spdlog.h>
 
+#if __has_include(<catch2/catch_all.hpp>)
 #include <catch2/catch_all.hpp>
 #include <catch2/reporters/catch_reporter_tap.hpp>
+#else
+#include <catch2/catch.hpp>
+#include <catch2/catch_reporter_tap.hpp>
+#endif
 #include <memory>
 
 int main(int argc, char* argv[]) {
@@ -13,10 +18,16 @@ int main(int argc, char* argv[]) {
 
   session.applyCommandLine(argc, argv);
   const auto logger = spdlog::default_logger();
+#if CATCH_VERSION_MAJOR >= 3
   for (const auto& spec : session.config().getReporterSpecs()) {
-    if (spec.name() == "tap") {
+    const auto& reporter_name = spec.name();
+#else
+  {
+    const auto& reporter_name = session.config().getReporterName();
+#endif
+    if (reporter_name == "tap") {
       spdlog::set_pattern("# [%l] %v");
-    } else if (spec.name() == "compact") {
+    } else if (reporter_name == "compact") {
       logger->sinks().clear();
     } else {
       logger->sinks().assign({std::make_shared<spdlog::sinks::stderr_sink_st>()});
